

export default {
  updateCheckInterval: 1000 * 60 * 60 * 24, // 24 hours
  psqlTimeout: 15000, // 5 seconds
  psqlIdleTimeout: 20000,
  defaultChunkSize: 100,
  largeFieldWidth: 300,
  maxColumnWidth: 1000,
  maxInitialWidth: 500,
  bigTableColumnWidth: 125
}


